#
# spec file for package python-tqdm
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define oldpython python
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without test
Name:           python-tqdm
Version:        4.19.8
Release:        lp150.1.1
Summary:        An extensible progress meter
License:        MPL-2.0 AND MIT
Group:          Development/Languages/Python
Url:            https://github.com/tqdm/tqdm
Source:         https://files.pythonhosted.org/packages/source/t/tqdm/tqdm-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module rpm-macros}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
%if %{with test}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
%endif
# /SECTION
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%python_subpackages

%description
tqdm lets you output a progress meter from within loops by wrapping
any iterable with "tqdm(iterable)".
tqdm's overhead is one order of magnitude less than python-progressbar
and does not require ncurses.

%prep
%setup -q -n tqdm-%{version}
# fix installation directory for man pages
sed -i 's#man/man1#share/man/man1#' setup.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/tqdm
%python_clone -a %{buildroot}%{_mandir}/man1/tqdm.1
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%{python_install_alternative tqdm tqdm.1}

%postun
%python_uninstall_alternative tqdm

%if %{with test}
%check
%python_exec %{_bindir}/nosetests --ignore-files="tests_perf\.py"
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc README.rst logo.png examples
%if 0%{?leap_version} >= 420200 || 0%{?suse_version} > 1320
%license LICENCE
%else
%doc LICENCE
%endif
%{python_sitelib}/*
%python_alternative %{_bindir}/tqdm
%python_alternative %{_mandir}/man1/tqdm.1

%changelog
* Sat Mar 17 2018 arun@gmx.de
- update to version 4.19.8:
  * TqdmMonitorWarning
  * warnings.warn
  * log.info
  * abstract and no-raise monitor error
* Sat Mar 17 2018 arun@gmx.de
- update to version 4.19.7:
  * fix: Avoid manipulating uninitialized instances on monitoring
    thread.
* Thu Mar  1 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 4.19.6:
  * CLI improvements
    + --bytes implies --unit B --unit_scale --unit_divisor 1024 (#503)
    + allow hyphens in CLI arguments (#511)
  * synchronisation: fix for sem_open on aarch64 (#513)
  * framework update
    + CI/tests, year 2018, py37, badges, documentation
* Sun Dec 10 2017 arun@gmx.de
- update to version 4.19.5:
  * multiprocess/lock fixes (#457)
  * set_description in notebook (#345 -> #475)
  * minor tidy (#476)
  * documentation updates
* Sun Oct 15 2017 arun@gmx.de
- update to version 4.19.4:
  * fix Lock:NotImplementedError on certain systems (#466 -> #468)
  * use recursive locks (#469 -> #468)
    + fix deadlocks
  * tidy (#448)
  * flush() on moveto() (#398 -> #399, #420, #467)
  * update tests and benchmarks
- changes from version 4.19.3:
  * no changelog available
* Tue Oct 10 2017 arun@gmx.de
- specfile:
  * added man page, fixed path for man-page in setup.py
  * added fdupes
- update to version 4.19.2:
  * flush() on refresh() (#459 from #317)
  * status printer updates (#331)
    + use sp() in refresh()
    + remove redundant clear():nomove=False
  * misc minor documentation updates
  * unit tests
- changes from version 4.19.1:
  * rate_(no)inv(_fmt) (#72, b228bc3)
  * __repr__() tidy (#389)
  * fix write() before initialisation AttributeError: _lock (#457)
  * man pages
  * documentation updates
* Fri Oct  6 2017 jengelh@inai.de
- Redo description with sensible content.
* Tue Oct  3 2017 arun@gmx.de
- update to version 4.18.0:
  * Thread safety! (#285 -> #291 -> #329, #407, #417)
  * Ease redirection of sys.stdout/stderr (#422)
  * Minor internal stream bugfix (#439)
  * AttributeError fixes (#323, #324, #418)
  * Related to:
    + Misc bugs (#334)
    + concurrent.futures (#97)
    + Multi-tqdm (#143)
    + flush() and refresh() (#331)
    + Newline on refresh() (#361)
    + Nested trees (#384)
    + Manually positioned nested bars clearing (#385)
* Sun Sep 24 2017 arun@gmx.de
- update to version 4.17.1:
  * __repr__() bugfix
  * better unicode detection
  * initialise `n` even when disabled
- changes from version 4.17.0:
  * easier redirect of stdout (#426 -> #431)
    + cls.external_write_mode() @contextmanager
  * refresh=True for set_description/update(_str) (#317 -> #377)
- changes from version 4.16.0:
  * more formatting control (#347 -> #362)
    + set_postfix_str(), set_description_str()
    + move ": " to bar_format
    + complements #266, #270
  * better CLI support (e.g. hyphenated paths) (#421 #423 -> #424)
  * more unit tests (#411)
    + upgrade to pypy2/3-5.8.0
    + add py37-dev
  * doc updates
- changes from version 4.15.0 :
  * minor fixes (#395)
  * minor documentation updates (#400, #401, #412)
  * better pandas support (#351 -> #409)
  * Jupyter notebook fix (#352, #369 -> #373, #405)
  * optimise setcheckinterval/setswitchinterval (#376)
  * add unit_scale (#273, #295 -> #378)
* Wed Jul  5 2017 sebix+novell.com@sebix.at
- upgrade specfile to singlespec
- upgrade to 4.14.0
* Wed Mar  1 2017 toddrme2178@gmail.com
- Update to 4.11.2
  * thread safety #332
  * address DeprecationWarning #319 -> #326
  * version extra #328 -> #330
    + security fix
    + add non-master branch name
    + Fixes BNC#1017485
    + Fixes CVE#CVE-2016-10075
  * minor safety
  * minor documentation and comments
- Update to 4.11.1
  * Officially support Python 3.6, addressing #333
- Update to 4.11.0
  * postfix argument added #266->#270
  * fix tests for
    + numpy #272->#302
    + PyPy3 #318->#325
  * 7z extraction example script
  * new logo #315
  * hit counter with logo colours and stats
  * documentation updates
  * safer setup.py Makefile emulation
  * better github contributions integrations and Code of Conduct #310
- update to version 4.10.0:
  * fix maxinterval to adjust miniters to mininterval #249
  * minor bugfixes (eg #288)
  * misc optimisations, unit tests, and benchmarks (eg #298)
  * documentation updates
- update to version 4.9.0:
  * monitoring thread to automatically to adjust miniters and avoid
    exceeding maxinterval
    + test race conditions
    + kill on KeyboardInterrupt + instant refresh
    + low performance overhead, option to disable
  * new CLI argument: --bytes to count chars
  * disable automatically on non-TTY (#281)
  * fixed refresh() and clear() if disabled (#286)
  * misc fixes
  * documentation
  * unit tests
  * optimisations, style fixes
  * codacy badge
  * safety and warning suppression
  * ignore coverall failures (#283)
  * fix broken link in README (#262)
  * Fix time() in refresh() + avoid write() races (#264)
  * Fix __repr__() #269
  * Fix update(0) causing ZeroDivisionError (on first call) #268
  * Faster simple bar for perf test (#257)
  * cleaner tqdm_notebook exit when not run in a notebook (#267)
  * Disable coveralls because of duplicate comments on github (#263)
  * Migrate codecov config -> codecov.yml
* Mon Sep 19 2016 toddrme2178@gmail.com
- update to version 4.8.4:
  * 14%% overhead reduction
  * fix exception when closing tqdm_notebook without a total
  * support more pandas modules
  * pandas.Series.progress_map
  * pandas.DataFrame.progress_applymap
  * Panel.progress_apply
  * PanelGroupBy.progress_apply
  * GroupBy.progress_aggregate
  * GroupBy.progress_transform
  * faster CI builds
  * misc documentation update and link to wiki
- update to version 4.8.3:
  (no changelog available)
- update to version 4.8.2:
  * custom tqdm warning/exceptions
  * tests now multiprocessed and include pandas
- update to version 4.8.1:
  * custom tqdm warning/exceptions
  * tests now multiprocessed and include pandas
- update to version 4.8.0:
  * tqdm.pandas classmethod replaces tqdm_pandas function (deprecated)
  * ipython aliased imports fixes
  * write without any instances
  * readme update
  * examples update
  * test fixes and updates
- update to version 4.7.6:
  * numpy len support, addressing #185
- update to version 4.7.5:
  * spring clean (mostly pragma)
  * addresses #182
  * series len, tests
  * disable support (fixes #184), fkake8 fixes
- update to version 4.7.4:
  * pandas.DataFrame.apply support
  * tqdm_notebook.write()
  * tqdm_gui.write()
  * misc notebook fixes
  * delay notebook imports (>80%% reduction in import time when unused)
  * optional colorama only on windows
  * documentation tidy
  * more & faster tests
- update to version 4.7.1:
  * pandas.DataFrame.apply support
- update to version 4.7.0:
  * CLI custom delimiter support
  * More robust CLI argument parsing
  * either one or two - preceding kwargs (eg -ascii or --ascii)
  * no positional args (so no need to quote multi-word -desc for
    example)
  * bool kwargs with implicit value=True still supported
  * optional = sign after kwargs
  * tests
  * doc updates, badges
  * pyversions, doi, licence, github
- update to version 4.6.2:
  * Fix warnings due to IPython/Jupyter widget
- update to version 4.6.1:
  * add IPython/Jupyter support
  * fix {bar} length breaking display when using custom bar_format
  * add a no inversion rate formatting for bar_format (i.e., always
    show it/s and never s/it)
- update to version 4.6.0:
  * (no changelog availabel)
- update to version 4.5.0:
  * print messages within (nested) loops using tqdm.write(...)
- update to version 4.4.3:
  * remove docopt dependency for CLI
  * re-added update(0) ability to trigger refresh
  * minor fixes
  * re-added (OSI approved) licence to source
  * dev versioning auto-fallback
  * slight speed optimisation
  * tests
  * documentation
- update to version 4.4.2:
  * no changelog available
- update to version 4.4.1:
  * remove "dumb binaries" from build, coverage
- update to version 4.4.0:
  * modularise
- update to version 4.3.0:
  * fix_position
  * tidy
- update to version 4.2.0:
  * licencizors
- update to version 4.1.0:
  * compat-fixes
- update to version 4.0.0:
  * automate nested
    + deprecate nested
    + add manual override control with position
  * documentation and example updates, coverage and tests
  * make leave==True by default (was False)
* Mon Feb  1 2016 arun@gmx.de
- update to version 3.8.0:
  * update(n<1) raises error
  * sanitise and update examples and README
  * fix setup.py encoding error
  * remove py32 from Travis
  * changelog more accessible from README
* Wed Jan 20 2016 toddrme2178@gmail.com
- Initial version
